Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3181)

Unified Diff: components/task_scheduler_util/browser/initialization.h

Issue 2749303002: [reference - do not submit] Always create four pools in TaskSchedulerImpl. (Closed)
Patch Set: rebase Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/task_scheduler_util/browser/initialization.h
diff --git a/components/task_scheduler_util/browser/initialization.h b/components/task_scheduler_util/browser/initialization.h
index d4584eeca4a8666438f7e414920f8fb719c67aeb..f636c0a34b28a11f62bc6e0ed541b779f77a31db 100644
--- a/components/task_scheduler_util/browser/initialization.h
+++ b/components/task_scheduler_util/browser/initialization.h
@@ -5,26 +5,16 @@
#ifndef COMPONENTS_TASK_SCHEDULER_UTIL_BROWSER_INITIALIZATION_H_
#define COMPONENTS_TASK_SCHEDULER_UTIL_BROWSER_INITIALIZATION_H_
-#include <stddef.h>
+#include <memory>
-#include <vector>
-
-#include "base/task_scheduler/scheduler_worker_pool_params.h"
-
-namespace base {
-class TaskTraits;
-}
+#include "base/task_scheduler/task_scheduler.h"
namespace task_scheduler_util {
-// Gets a vector of SchedulerWorkerPoolParams to initialize TaskScheduler in the
-// browser based off variations. Returns an empty vector on failure.
-std::vector<base::SchedulerWorkerPoolParams>
-GetBrowserWorkerPoolParamsFromVariations();
-
-// Maps |traits| to the index of a browser worker pool vector provided by
-// GetBrowserWorkerPoolParamsFromVariations().
-size_t BrowserWorkerPoolIndexForTraits(const base::TaskTraits& traits);
+// Gets a TaskSchedulerInitParams object to initialize TaskScheduler in the
+// browser based off variations. Returns nullptr on failure.
+std::unique_ptr<base::TaskSchedulerInitParams>
+GetBrowserTaskSchedulerInitParamsFromVariations();
// Redirects zero-to-many PostTask APIs to the browser task scheduler based off
// variations.
« no previous file with comments | « chrome/renderer/chrome_content_renderer_client.cc ('k') | components/task_scheduler_util/browser/initialization.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698